/*************************************************************
 *
 *  MathJax/jax/output/HTML-CSS/fonts/STIX-Web/Normal/Italic/Main.js
 *  
 *  Copyright (c) 2013-2020 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['STIXMathJax_Normal-italic'] = {
  directory: 'Normal/Italic',
  family: 'STIXMathJax_Normal',
  style: 'italic',
  testString: '\u00A0\u210E\uD835\uDC34\uD835\uDC35\uD835\uDC36\uD835\uDC37\uD835\uDC38\uD835\uDC39\uD835\uDC3A\uD835\uDC3B\uD835\uDC3C\uD835\uDC3D\uD835\uDC3E\uD835\uDC3F\uD835\uDC40',
  skew: {
    0x1D434: .16,
    0x1D435: .14,
    0x1D436: .12,
    0x1D437: .1,
    0x1D438: .1,
    0x1D439: .1,
    0x1D43A: .12,
    0x1D43B: .1,
    0x1D43C: .1,
    0x1D43D: .1,
    0x1D43E: .1,
    0x1D43F: .05,
    0x1D440: .08,
    0x1D441: .08,
    0x1D442: .12,
    0x1D443: .05,
    0x1D444: .12,
    0x1D445: .1,
    0x1D446: .12,
    0x1D44B: .12,
    0x1D44C: -.05,
    0x1D44D: .1,
    0x1D44E: .09,
    0x1D44F: .03,
    0x1D450: .09,
    0x1D451: .2,
    0x1D452: .09,
    0x1D453: .19,
    0x1D454: .08,
    0x1D456: .08,
    0x1D457: .16,
    0x1D459: .09,
    0x1D45A: .09,
    0x1D45B: .05,
    0x1D45C: .09,
    0x1D45D: .09,
    0x1D45E: .1,
    0x1D45F: .07,
    0x1D460: .07,
    0x1D461: .07,
    0x1D462: .05,
    0x1D463: .08,
    0x1D464: .1,
    0x1D465: .05,
    0x1D466: .1,
    0x1D467: .07,
    0x1D6A4: .05,
    0x1D6A5: .07,
    0x1D6E2: .16,
    0x1D6E3: .14,
    0x1D6E4: .09,
    0x1D6E5: .16,
    0x1D6E6: .14,
    0x1D6E7: .14,
    0x1D6E8: .1,
    0x1D6E9: .12,
    0x1D6EA: .1,
    0x1D6EB: .12,
    0x1D6EC: .16,
    0x1D6ED: .12,
    0x1D6EE: .1,
    0x1D6EF: .14,
    0x1D6F0: .14,
    0x1D6F1: .12,
    0x1D6F2: .08,
    0x1D6F3: .14,
    0x1D6F4: .14,
    0x1D6F7: .12,
    0x1D6F8: .14,
    0x1D6FA: .16,
    0x1D6FB: .05,
    0x1D6FC: .05,
    0x1D6FD: .1,
    0x1D6FE: .05,
    0x1D6FF: .12,
    0x1D700: .07,
    0x1D701: .07,
    0x1D702: .05,
    0x1D703: .09,
    0x1D704: .05,
    0x1D706: .07,
    0x1D707: .1,
    0x1D708: .07,
    0x1D709: .12,
    0x1D70A: .08,
    0x1D70B: .08,
    0x1D70C: .1,
    0x1D70D: .1,
    0x1D70E: .05,
    0x1D710: .05,
    0x1D711: .05,
    0x1D712: .09,
    0x1D714: .05,
    0x1D716: .1,
    0x1D717: .1,
    0x1D71A: .1,
    0x1D71B: .07,
  },
  0x20: [0,0,250,0,0],
  0xA0: [0,0,250,0,0],
  0x210E: [668,11,513,45,483],
  0x1D434: [667,0,717,35,685],
  0x1D435: [653,0,696,38,686],
  0x1D436: [659,12,671,50,711],
  0x1D437: [653,0,790,38,765],
  0x1D438: [653,0,714,38,734],
  0x1D439: [653,0,618,38,723],
  0x1D43A: [668,12,734,50,734],
  0x1D43B: [653,0,873,38,923],
  0x1D43C: [653,0,480,38,530],
  0x1D43D: [653,12,540,60,620],
  0x1D43E: [653,0,762,38,802],
  0x1D43F: [653,0,708,38,668],
  0x1D440: [653,0,1005,38,1055],
  0x1D441: [653,0,851,38,901],
  0x1D442: [669,11,732,50,712],
  0x1D443: [653,0,594,38,704],
  0x1D444: [667,152,781,50,731],
  0x1D445: [653,0,740,38,725],
  0x1D446: [668,10,650,50,680],
  0x1D447: [653,0,550,25,670],
  0x1D448: [653,13,705,65,775],
  0x1D449: [653,16,575,60,760],
  0x1D44A: [653,16,916,60,1101],
  0x1D44B: [653,0,790,25,810],
  0x1D44C: [653,0,535,35,695],
  0x1D44D: [653,0,772,60,802],
  0x1D44E: [441,10,502,40,472],
  0x1D44F: [668,11,470,45,450],
  0x1D450: [441,11,415,40,400],
  0x1D451: [668,12,532,40,527],
  0x1D452: [441,11,445,40,410],
  0x1D453: [668,187,555,40,615],
  0x1D454: [441,187,492,20,492],
  0x1D456: [616,11,311,50,257],
  0x1D457: [616,187,389,-16,372],
  0x1D458: [668,11,542,45,527],
  0x1D459: [668,10,318,45,278],
  0x1D45A: [441,8,710,30,680],
  0x1D45B: [441,8,497,30,467],
  0x1D45C: [441,11,458,40,438],
  0x1D45D: [441,183,489,-30,474],
  0x1D45E: [441,183,458,40,463],
  0x1D45F: [441,0,408,30,393],
  0x1D460: [441,11,440,50,390],
  0x1D461: [567,9,313,40,283],
  0x1D462: [441,9,474,30,444],
  0x1D463: [458,9,506,72,479],
  0x1D464: [460,9,775,72,748],
  0x1D465: [441,9,550,30,510],
  0x1D466: [440,183,496,30,496],
  0x1D467: [450,14,499,42,467],
  0x1D6A4: [441,11,278,47,235],
  0x1D6A5: [441,207,278,-124,246],
  0x1D6E2: [667,0,717,35,685],
  0x1D6E3: [653,0,696,38,686],
  0x1D6E4: [653,0,616,38,721],
  0x1D6E5: [667,0,596,30,556],
  0x1D6E6: [653,0,714,38,734],
  0x1D6E7: [653,0,772,60,802],
  0x1D6E8: [653,0,873,38,923],
  0x1D6E9: [669,11,737,50,712],
  0x1D6EA: [653,0,480,38,530],
  0x1D6EB: [653,0,762,38,802],
  0x1D6EC: [667,0,718,35,686],
  0x1D6ED: [653,0,1005,38,1055],
  0x1D6EE: [653,0,851,38,901],
  0x1D6EF: [653,0,706,52,741],
  0x1D6F0: [669,11,732,50,712],
  0x1D6F1: [653,0,873,38,923],
  0x1D6F2: [653,0,594,38,704],
  0x1D6F3: [669,11,737,50,712],
  0x1D6F4: [653,0,735,58,760],
  0x1D6F5: [653,0,550,25,670],
  0x1D6F6: [668,0,613,28,743],
  0x1D6F7: [653,0,772,25,747],
  0x1D6F8: [653,0,790,25,810],
  0x1D6F9: [667,0,670,28,743],
  0x1D6FA: [666,0,800,32,777],
  0x1D6FB: [653,15,627,42,600],
  0x1D6FC: [441,10,524,40,529],
  0x1D6FD: [668,183,493,25,518],
  0x1D6FE: [441,187,428,35,458],
  0x1D6FF: [668,11,463,40,451],
  0x1D700: [441,11,484,25,444],
  0x1D701: [668,183,435,40,480],
  0x1D702: [441,183,460,30,455],
  0x1D703: [668,11,484,40,474],
  0x1D704: [441,11,267,50,227],
  0x1D705: [441,0,534,50,549],
  0x1D706: [668,16,541,50,511],
  0x1D707: [428,183,579,30,549],
  0x1D708: [446,9,452,50,462],
  0x1D709: [668,183,433,25,443],
  0x1D70A: [441,11,458,40,438],
  0x1D70B: [428,13,558,35,568],
  0x1D70C: [441,183,502,30,472],
  0x1D70D: [490,183,439,35,464],
  0x1D70E: [428,11,537,40,547],
  0x1D70F: [428,5,442,30,472],
  0x1D710: [439,11,460,30,445],
  0x1D711: [441,183,666,50,631],
  0x1D712: [441,202,595,30,645],
  0x1D713: [441,183,661,30,711],
  0x1D714: [441,11,681,20,661],
  0x1D715: [668,11,471,40,471],
  0x1D716: [441,11,430,40,430],
  0x1D717: [678,10,554,20,507],
  0x1D718: [441,13,561,12,587],
  0x1D719: [668,183,645,40,620],
  0x1D71A: [441,187,509,40,489],
  0x1D71B: [428,11,856,30,866]
};

MathJax.Callback.Queue(
  ["initFont",MathJax.OutputJax["HTML-CSS"],"STIXMathJax_Normal-italic"],
  ["loadComplete",MathJax.Ajax,MathJax.OutputJax["HTML-CSS"].fontDir+"/Normal/Italic/Main.js"]
);
